#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME="nodered/node-red:latest"
}

do_install_detail() {
  local config=`uci get nodered.@nodered[0].config_path 2>/dev/null`
  local port=`uci get nodered.@nodered[0].port 2>/dev/null`
  local IMAGE_NAME=`uci get nodered.@nodered[0].image_name 2>/dev/null`
  local username=`uci get nodered.@nodered[0].username 2>/dev/null`
  local password=`uci get nodered.@nodered[0].password 2>/dev/null`

  #Generate the generic environment variables for the docker-compose

  GEN_PASS=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  GEN_PASS2=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  
  # Get our local LAN IP Address
  LAN_IP=$(uci get network.lan.ipaddr)
  # Strip trailing network mask
  LAN_IP="${LAN_IP%/*}"
   
  if [ -z "$config" ]; then
      echo "config path is empty!"
      exit 1
  fi

  [ -z "$port" ] && port=1880
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME=nodered/node-red:latest

  
  # Create Docker Compose file with custom variables
   
  # Create Docker Compose file with custom variables
touch docker-compose.yml
cat > docker-compose.yml <<EOF
version: "3.7"

services:
  node-red:
    image: nodered/node-red:latest
    environment:
      - TZ=Europe/Amsterdam
    ports:
      - "$port:1880"
    networks:
      - node-red-net
    volumes:
      - node-red-data:/data

volumes:
  node-red-data:

networks:
  node-red-net:
EOF
  
  docker-compose up -d
 
  # Add a new list option to the "shortcutmenu" configuration file
  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu

}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install nodered"
  echo "      upgrade                Upgrade nodered"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart nodered"
  echo "      status                 nodered status"
  echo "      port                   nodered port"
}

case ${ACTION} in
  "install")
    get_image
    do_install_detail
  ;;
  "upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    docker rm -f nodered
  ;;
  "start" | "stop" | "restart")
    docker ${ACTION} nodered
  ;;
  "status")
    docker ps --all -f 'name=nodered' --format '{{.State}}'
  ;;
  "port")
    docker ps --all -f 'name=nodered' --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
